@@ -67,7 +67,18 @@ class ManagedInstanceRole(
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ManagedInstanceRole.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                create_instance_profile: typing.Optional[builtins.bool] = None,
+                domain_join_enabled: typing.Optional[builtins.bool] = None,
+                managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
+                retention_policy: typing.Optional[builtins.bool] = None,
+                ssm_management_enabled: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ManagedInstanceRoleProps(
@@ -134,7 +145,16 @@ class ManagedInstanceRoleProps:
         :param ssm_management_enabled: Should the role include SSM management. By default if domainJoinEnabled is true then this role is always included.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ManagedInstanceRoleProps.__init__)
+            def stub(
+                *,
+                create_instance_profile: typing.Optional[builtins.bool] = None,
+                domain_join_enabled: typing.Optional[builtins.bool] = None,
+                managed_policies: typing.Optional[typing.Sequence[aws_cdk.aws_iam.ManagedPolicy]] = None,
+                retention_policy: typing.Optional[builtins.bool] = None,
+                ssm_management_enabled: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument create_instance_profile", value=create_instance_profile, expected_type=type_hints["create_instance_profile"])
             check_type(argname="argument domain_join_enabled", value=domain_join_enabled, expected_type=type_hints["domain_join_enabled"])
             check_type(argname="argument managed_policies", value=managed_policies, expected_type=type_hints["managed_policies"])
